package cmdUser

import (
	"bytes"

	nc "gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/libclient/nexusclient"

	u "gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/client/utils"

	"golang.org/x/crypto/ssh/terminal"
)

type UpdatePwd struct {
	Name string
}

func (cmd *UpdatePwd) GetName() string {
	return cmd.Name
}

func (cmd *UpdatePwd) GetDesc() []string {
	return []string{
		"Updates the current user's password."}
}

func (cmd *UpdatePwd) PrintUsage() {
	for _, desc := range cmd.GetDesc() {
		u.PrintlnErr(desc)
	}
	u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
	u.PrintlnErr("USAGE: " + cmd.GetName())
	u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
}

func (cmd *UpdatePwd) Run(nc *nc.NexusClient, args []string) int {
	argc := len(args)
	if argc != 0 {
		cmd.PrintUsage()
		return 1
	}

	// Read the new password from stdin
	u.Print("New password: ")
	newPwd, err := terminal.ReadPassword(0)
	if err != nil {
		u.PrintlnErr("Error: " + err.Error())
		return 1
	}
	u.Print("\nRetype new password: ")
	newPwd2, err := terminal.ReadPassword(0)
	if err != nil {
		u.PrintlnErr("Error: " + err.Error())
		return 1
	}
	u.Println("")

	if !bytes.Equal(newPwd, newPwd2) {
		u.PrintlnErr("Error: passwords do not match!")
		u.PrintlnErr("Password unchanged.")
		return 1
	}

	err = nc.UserUpdatePwd(string(newPwd))
	if err != nil {
		u.PrintlnErr(err)
		return 1
	}

	u.Println("Password changed successfully.")
	return 0
}
