package cmdVM

import (
	"sync"

	u "gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/client/utils"
	nc "gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/libclient/nexusclient"
)

type AttachSync struct {
	Name string
}

func (cmd *AttachSync) GetName() string {
	return cmd.Name
}

func (cmd *AttachSync) GetDesc() []string {
	return []string{
		"Attaches to one or more VMs in order to use their desktop environment.",
		"If not the VM's owner: requires VM_ATTACH VM access capability or VM_ATTACH_ANY user capability."}
}

func (cmd *AttachSync) PrintUsage() {
	printRegexUsage(cmd)
	printRegexUsageDetails()
}

func (cmd *AttachSync) Run(nc *nc.NexusClient, args []string) int {
	argc := len(args)
	if argc < 1 {
		cmd.PrintUsage()
		return 1
	}

	credsList, err := getFilteredAttachVMsCreds(nc, args)
	if err != nil {
		u.PrintlnErr(err)
		return 1
	}

	if len(credsList) == 0 {
		u.PrintlnErr("No matching VMs.")
	}

	// Use wait groups to wait until all viewers threads have completed.
	var wg sync.WaitGroup
	wg.Add(len(credsList))

	for _, creds := range credsList {
		go func() {
			err := nc.VMAttachFromCreds(creds, false)
			if err != nil {
				u.PrintlnErr("Failed attach to VM: " + err.Error())
			}
			wg.Done()
		}()
	}

	wg.Wait()

	return 0
}
