package cmdVM

import (
	nc "gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/libclient/nexusclient"

	u "gitedu.hesge.ch/flg_projects/nexus_vdi/nexus/client/utils"
)

type Shutdown struct {
	Name string
}

func (cmd *Shutdown) GetName() string {
	return cmd.Name
}

func (cmd *Shutdown) GetDesc() []string {
	return []string{
		"Gracefully shutdowns one or more VMs.",
		"If not the VM's owner: requires VM_STOP VM access capability or VM_STOP_ANY user capability."}
}

func (cmd *Shutdown) PrintUsage() {
	printRegexUsage(cmd)
	printRegexUsageDetails()
}

func (cmd *Shutdown) Run(nc *nc.NexusClient, args []string) int {
	argc := len(args)
	if argc < 1 {
		cmd.PrintUsage()
		return 1
	}

	vms, err := getFilteredVMs(nc.GetStopVMs, args)
	if err != nil {
		u.PrintlnErr(err)
		return 1
	}

	if len(vms) == 0 {
		u.PrintlnErr("Error: VM(s) not found.")
		return 1
	}

	statusCode := 0

	for _, vm := range vms {
		err := nc.VMShutdown(vm.ID.String())
		if err != nil {
			u.PrintlnErr(err)
			statusCode = 1
		} else {
			u.Println("Sent shutdown message to VM \"" + vm.Name + "\"")
		}
	}

	return statusCode
}
