package utils

import (
	"math/rand"
	"net"
	"strconv"
)

// Returns a random MAC address as a string (e.g. "b3:30:49:f8:d0:4b").
func RandMacAddress() (string, error) {
	buf := make([]byte, 6)
	_, err := rand.Read(buf)
	if err != nil {
		return "", err
	}

	// Sets unicast mode (bit 0 to 0) and locally administered addresses (bit 1 to 1)
	// For more details, see: https://en.wikipedia.org/wiki/MAC_address#Universal_vs._local_(U/L_bit)
	buf[0] &= 0xFE
	buf[0] |= 2

	var mac net.HardwareAddr
	mac = append(mac, buf[0], buf[1], buf[2], buf[3], buf[4], buf[5])
	return mac.String(), nil
}

// Returns true if the specified TCP port is available, false otherwise.
func IsPortAvailable(port int) bool {
	ln, err := net.Listen("tcp", ":"+strconv.Itoa(port))
	if err != nil {
		return false
	}
	ln.Close()
	return true
}
